EvaluationMode enum

The evaluation mode of the Hackle SDK.

Inheritance
Available extensions

Values

local → const EvaluationMode

Evaluates locally with the workspace configuration fetched by the client. (default)

remote → const EvaluationMode

Reads the evaluation results that the server has pre-evaluated.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<EvaluationMode>
A constant List of the values in this enum, in order of their declaration.