HackleSessionTimeoutCondition class

Properties

hashCode int
The hash code for this object.
no setterinherited
onApplicationStateChange bool?
final
onBackground bool?
final
onForeground bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeoutMillis int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited