HackleSessionTimeoutConditionBuilder class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → HackleSessionTimeoutCondition -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onApplicationStateChange(
bool onApplicationStateChange) → HackleSessionTimeoutConditionBuilder -
onBackground(
bool onBackground) → HackleSessionTimeoutConditionBuilder -
onForeground(
bool onForeground) → HackleSessionTimeoutConditionBuilder -
timeoutMillis(
int timeoutMillis) → HackleSessionTimeoutConditionBuilder -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited